==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/DomainLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.DomainLinksAllOfBrand;
import com.okta.sdk.resource.model.DomainLinksAllOfCertificate;
import com.okta.sdk.resource.model.DomainLinksAllOfVerify;
import com.okta.sdk.resource.model.HrefObjectSelfLink;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * DomainLinks
 */
@JsonPropertyOrder({ DomainLinks.JSON_PROPERTY_SELF, DomainLinks.JSON_PROPERTY_BRAND,
        DomainLinks.JSON_PROPERTY_CERTIFICATE, DomainLinks.JSON_PROPERTY_VERIFY })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class DomainLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SELF = "self";
    private HrefObjectSelfLink self;

    public static final String JSON_PROPERTY_BRAND = "brand";
    private DomainLinksAllOfBrand brand;

    public static final String JSON_PROPERTY_CERTIFICATE = "certificate";
    private DomainLinksAllOfCertificate certificate;

    public static final String JSON_PROPERTY_VERIFY = "verify";
    private DomainLinksAllOfVerify verify;

    public DomainLinks() {
    }

    public DomainLinks self(HrefObjectSelfLink self) {

        this.self = self;
        return this;
    }

    /**
     * Get self
     *
     * @return self
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectSelfLink getSelf() {
        return self;
    }

    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSelf(HrefObjectSelfLink self) {
        this.self = self;
    }

    public DomainLinks brand(DomainLinksAllOfBrand brand) {

        this.brand = brand;
        return this;
    }

    /**
     * Get brand
     *
     * @return brand
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_BRAND)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DomainLinksAllOfBrand getBrand() {
        return brand;
    }

    @JsonProperty(JSON_PROPERTY_BRAND)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setBrand(DomainLinksAllOfBrand brand) {
        this.brand = brand;
    }

    public DomainLinks certificate(DomainLinksAllOfCertificate certificate) {

        this.certificate = certificate;
        return this;
    }

    /**
     * Get certificate
     *
     * @return certificate
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CERTIFICATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DomainLinksAllOfCertificate getCertificate() {
        return certificate;
    }

    @JsonProperty(JSON_PROPERTY_CERTIFICATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCertificate(DomainLinksAllOfCertificate certificate) {
        this.certificate = certificate;
    }

    public DomainLinks verify(DomainLinksAllOfVerify verify) {

        this.verify = verify;
        return this;
    }

    /**
     * Get verify
     *
     * @return verify
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_VERIFY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DomainLinksAllOfVerify getVerify() {
        return verify;
    }

    @JsonProperty(JSON_PROPERTY_VERIFY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setVerify(DomainLinksAllOfVerify verify) {
        this.verify = verify;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        DomainLinks domainLinks = (DomainLinks) o;
        return Objects.equals(this.self, domainLinks.self) && Objects.equals(this.brand, domainLinks.brand)
                && Objects.equals(this.certificate, domainLinks.certificate)
                && Objects.equals(this.verify, domainLinks.verify);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(self, brand, certificate, verify);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class DomainLinks {\n");
        sb.append("    self: ").append(toIndentedString(self)).append("\n");
        sb.append("    brand: ").append(toIndentedString(brand)).append("\n");
        sb.append("    certificate: ").append(toIndentedString(certificate)).append("\n");
        sb.append("    verify: ").append(toIndentedString(verify)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/DomainLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.DomainLinksAllOfBrand;
import com.okta.sdk.resource.model.DomainLinksAllOfCertificate;
import com.okta.sdk.resource.model.DomainLinksAllOfVerify;
import com.okta.sdk.resource.model.HrefObjectSelfLink;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * DomainLinks
 */
@JsonPropertyOrder({ DomainLinks.JSON_PROPERTY_SELF, DomainLinks.JSON_PROPERTY_BRAND,
        DomainLinks.JSON_PROPERTY_CERTIFICATE, DomainLinks.JSON_PROPERTY_VERIFY })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class DomainLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SELF = "self";
    private HrefObjectSelfLink self;

    public static final String JSON_PROPERTY_BRAND = "brand";
    private DomainLinksAllOfBrand brand;

    public static final String JSON_PROPERTY_CERTIFICATE = "certificate";
    private DomainLinksAllOfCertificate certificate;

    public static final String JSON_PROPERTY_VERIFY = "verify";
    private DomainLinksAllOfVerify verify;

    public DomainLinks() {
    }

    public DomainLinks self(HrefObjectSelfLink self) {

        this.self = self;
        return this;
    }

    /**
     * Get self
     *
     * @return self
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectSelfLink getSelf() {
        return self;
    }

    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSelf(HrefObjectSelfLink self) {
        this.self = self;
    }

    public DomainLinks brand(DomainLinksAllOfBrand brand) {

        this.brand = brand;
        return this;
    }

    /**
     * Get brand
     *
     * @return brand
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_BRAND)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DomainLinksAllOfBrand getBrand() {
        return brand;
    }

    @JsonProperty(JSON_PROPERTY_BRAND)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setBrand(DomainLinksAllOfBrand brand) {
        this.brand = brand;
    }

    public DomainLinks certificate(DomainLinksAllOfCertificate certificate) {

        this.certificate = certificate;
        return this;
    }

    /**
     * Get certificate
     *
     * @return certificate
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CERTIFICATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DomainLinksAllOfCertificate getCertificate() {
        return certificate;
    }

    @JsonProperty(JSON_PROPERTY_CERTIFICATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCertificate(DomainLinksAllOfCertificate certificate) {
        this.certificate = certificate;
    }

    public DomainLinks verify(DomainLinksAllOfVerify verify) {

        this.verify = verify;
        return this;
    }

    /**
     * Get verify
     *
     * @return verify
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_VERIFY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DomainLinksAllOfVerify getVerify() {
        return verify;
    }

    @JsonProperty(JSON_PROPERTY_VERIFY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setVerify(DomainLinksAllOfVerify verify) {
        this.verify = verify;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        DomainLinks domainLinks = (DomainLinks) o;
        return Objects.equals(this.self, domainLinks.self) && Objects.equals(this.brand, domainLinks.brand)
                && Objects.equals(this.certificate, domainLinks.certificate)
                && Objects.equals(this.verify, domainLinks.verify);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(self, brand, certificate, verify);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class DomainLinks {\n");
        sb.append("    self: ").append(toIndentedString(self)).append("\n");
        sb.append("    brand: ").append(toIndentedString(brand)).append("\n");
        sb.append("    certificate: ").append(toIndentedString(certificate)).append("\n");
        sb.append("    verify: ").append(toIndentedString(verify)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
